==> xboard-4.0.7.tar.gz: xboard-4.0.7/bitmaps/bitmaps.h <==
/*
 * bitmaps.h - Include bitmap files for pieces and icons
 * $Id: bitmaps.h,v 1.10 1999/02/26 03:42:14 mann Exp $
 *
 * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
 * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
 *
 * The following terms apply to Digital Equipment Corporation's copyright
 * interest in XBoard:
 * ------------------------------------------------------------------------
 * All Rights Reserved
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and that
 * both that copyright notice and this permission notice appear in
 * supporting documentation, and that the name of Digital not be
 * used in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.
 *
 * DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
 * ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
 * DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
 * ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 * SOFTWARE.
 * ------------------------------------------------------------------------
 *
 * The following terms apply to the enhanced version of XBoard distributed
 * by the Free Software Foundation:
 * ------------------------------------------------------------------------
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * ------------------------------------------------------------------------
 *
 * See the file ChangeLog for a revision history.
 */

#include "p129s.bm"
#include "n129s.bm"
#include "b129s.bm"
#include "r129s.bm"
#include "q129s.bm"
#include "k129s.bm"

#include "p129o.bm"
#include "n129o.bm"
#include "b129o.bm"
#include "r129o.bm"
#include "q129o.bm"
#include "k129o.bm"

#include "p116s.bm"
#include "n116s.bm"
#include "b116s.bm"
#include "r116s.bm"
#include "q116s.bm"
#include "k116s.bm"

#include "p116o.bm"
#include "n116o.bm"
#include "b116o.bm"
#include "r116o.bm"
#include "q116o.bm"
#include "k116o.bm"

#include "p108s.bm"
#include "n108s.bm"
#include "b108s.bm"
#include "r108s.bm"
#include "q108s.bm"
#include "k108s.bm"

#include "p108o.bm"
#include "n108o.bm"
#include "b108o.bm"
#include "r108o.bm"
#include "q108o.bm"
#include "k108o.bm"

#include "p95s.bm"
#include "n95s.bm"
#include "b95s.bm"
#include "r95s.bm"
#include "q95s.bm"
#include "k95s.bm"

#include "p95o.bm"
#include "n95o.bm"
#include "b95o.bm"
#include "r95o.bm"
#include "q95o.bm"
#include "k95o.bm"

#include "p87s.bm"
#include "n87s.bm"
#include "b87s.bm"
#include "r87s.bm"
#include "q87s.bm"
#include "k87s.bm"

#include "p87o.bm"
#include "n87o.bm"
#include "b87o.bm"
#include "r87o.bm"
#include "q87o.bm"
#include "k87o.bm"

#include "p80s.bm"
#include "n80s.bm"
#include "b80s.bm"
#include "r80s.bm"
#include "q80s.bm"
#include "k80s.bm"

#include "p80o.bm"
#include "n80o.bm"
#include "b80o.bm"
#include "r80o.bm"
#include "q80o.bm"
#include "k80o.bm"

#include "p72s.bm"
#include "n72s.bm"
#include "b72s.bm"
#include "r72s.bm"
#include "q72s.bm"
#include "k72s.bm"

#include "p72o.bm"
#include "n72o.bm"
#include "b72o.bm"
#include "r72o.bm"
#include "q72o.bm"
#include "k72o.bm"

#include "p64s.bm"
#include "n64s.bm"
#include "b64s.bm"
#include "r64s.bm"
#include "q64s.bm"
#include "k64s.bm"

#include "p64o.bm"
#include "n64o.bm"
#include "b64o.bm"
#include "r64o.bm"
#include "q64o.bm"
#include "k64o.bm"

#include "p58s.bm"
#include "n58s.bm"
#include "b58s.bm"
#include "r58s.bm"
#include "q58s.bm"
#include "k58s.bm"

#include "p58o.bm"
#include "n58o.bm"
#include "b58o.bm"
#include "r58o.bm"
#include "q58o.bm"
#include "k58o.bm"

#include "p54s.bm"
#include "n54s.bm"
#include "b54s.bm"
#include "r54s.bm"
#include "q54s.bm"
#include "k54s.bm"

#include "p54o.bm"
#include "n54o.bm"
#include "b54o.bm"
#include "r54o.bm"
#include "q54o.bm"
#include "k54o.bm"

#include "p49s.bm"
#include "n49s.bm"
#include "b49s.bm"
#include "r49s.bm"
#include "q49s.bm"
#include "k49s.bm"

#include "p49o.bm"
#include "n49o.bm"
#include "b49o.bm"
#include "r49o.bm"
#include "q49o.bm"
#include "k49o.bm"

#include "p45s.bm"
#include "n45s.bm"
#include "b45s.bm"
#include "r45s.bm"
#include "q45s.bm"
#include "k45s.bm"

#include "p45o.bm"
#include "n45o.bm"
#include "b45o.bm"
#include "r45o.bm"
#include "q45o.bm"
#include "k45o.bm"

#include "p40s.bm"
#include "n40s.bm"
#include "b40s.bm"
#include "r40s.bm"
#include "q40s.bm"
#include "k40s.bm"

#include "p40o.bm"
#include "n40o.bm"
#include "b40o.bm"
#include "r40o.bm"
#include "q40o.bm"
#include "k40o.bm"

#include "p37s.bm"
#include "n37s.bm"
#include "b37s.bm"
#include "r37s.bm"
#include "q37s.bm"
#include "k37s.bm"

#include "p37o.bm"
#include "n37o.bm"
#include "b37o.bm"
#include "r37o.bm"
#include "q37o.bm"
#include "k37o.bm"

#include "p33s.bm"
#include "n33s.bm"
#include "b33s.bm"
#include "r33s.bm"
#include "q33s.bm"
#include "k33s.bm"

#include "p33o.bm"
#include "n33o.bm"
#include "b33o.bm"
#include "r33o.bm"
#include "q33o.bm"
#include "k33o.bm"

#include "p29s.bm"
#include "n29s.bm"
#include "b29s.bm"
#include "r29s.bm"
#include "q29s.bm"
#include "k29s.bm"

#include "p29o.bm"
#include "n29o.bm"
#include "b29o.bm"
#include "r29o.bm"
#include "q29o.bm"
#include "k29o.bm"

#include "p25s.bm"
#include "n25s.bm"
#include "b25s.bm"
#include "r25s.bm"
#include "q25s.bm"
#include "k25s.bm"

#include "p25o.bm"
#include "n25o.bm"
#include "b25o.bm"
#include "r25o.bm"
#include "q25o.bm"
#include "k25o.bm"

#include "p21s.bm"
#include "n21s.bm"
#include "b21s.bm"
#include "r21s.bm"
#include "q21s.bm"
#include "k21s.bm"

#include "p21o.bm"
#include "n21o.bm"
#include "b21o.bm"
#include "r21o.bm"
#include "q21o.bm"
#include "k21o.bm"

#define BUILT_IN_BITS {\
{ 129,\
  { { p129s_bits, n129s_bits, b129s_bits, r129s_bits, q129s_bits, k129s_bits },\
    { p129o_bits, n129o_bits, b129o_bits, r129o_bits, q129o_bits, k129o_bits } } },\
{ 116,\
  { { p116s_bits, n116s_bits, b116s_bits, r116s_bits, q116s_bits, k116s_bits },\
    { p116o_bits, n116o_bits, b116o_bits, r116o_bits, q116o_bits, k116o_bits } } },\
{ 108,\
  { { p108s_bits, n108s_bits, b108s_bits, r108s_bits, q108s_bits, k108s_bits },\
    { p108o_bits, n108o_bits, b108o_bits, r108o_bits, q108o_bits, k108o_bits } } },\
{ 95,\
  { { p95s_bits, n95s_bits, b95s_bits, r95s_bits, q95s_bits, k95s_bits },\
    { p95o_bits, n95o_bits, b95o_bits, r95o_bits, q95o_bits, k95o_bits } } },\
{ 87,\
  { { p87s_bits, n87s_bits, b87s_bits, r87s_bits, q87s_bits, k87s_bits },\
    { p87o_bits, n87o_bits, b87o_bits, r87o_bits, q87o_bits, k87o_bits } } },\
{ 80,\
  { { p80s_bits, n80s_bits, b80s_bits, r80s_bits, q80s_bits, k80s_bits },\
    { p80o_bits, n80o_bits, b80o_bits, r80o_bits, q80o_bits, k80o_bits } } },\
{ 72,\
  { { p72s_bits, n72s_bits, b72s_bits, r72s_bits, q72s_bits, k72s_bits },\
    { p72o_bits, n72o_bits, b72o_bits, r72o_bits, q72o_bits, k72o_bits } } },\
{ 64,\
  { { p64s_bits, n64s_bits, b64s_bits, r64s_bits, q64s_bits, k64s_bits },\
    { p64o_bits, n64o_bits, b64o_bits, r64o_bits, q64o_bits, k64o_bits } } },\
{ 58,\
  { { p58s_bits, n58s_bits, b58s_bits, r58s_bits, q58s_bits, k58s_bits },\
    { p58o_bits, n58o_bits, b58o_bits, r58o_bits, q58o_bits, k58o_bits } } },\
{ 54,\
  { { p54s_bits, n54s_bits, b54s_bits, r54s_bits, q54s_bits, k54s_bits },\
    { p54o_bits, n54o_bits, b54o_bits, r54o_bits, q54o_bits, k54o_bits } } },\
{ 49,\
  { { p49s_bits, n49s_bits, b49s_bits, r49s_bits, q49s_bits, k49s_bits },\
    { p49o_bits, n49o_bits, b49o_bits, r49o_bits, q49o_bits, k49o_bits } } },\
{ 45,\
  { { p45s_bits, n45s_bits, b45s_bits, r45s_bits, q45s_bits, k45s_bits },\
    { p45o_bits, n45o_bits, b45o_bits, r45o_bits, q45o_bits, k45o_bits } } },\
{ 40,\
  { { p40s_bits, n40s_bits, b40s_bits, r40s_bits, q40s_bits, k40s_bits },\
    { p40o_bits, n40o_bits, b40o_bits, r40o_bits, q40o_bits, k40o_bits } } },\
{ 37,\
  { { p37s_bits, n37s_bits, b37s_bits, r37s_bits, q37s_bits, k37s_bits },\
    { p37o_bits, n37o_bits, b37o_bits, r37o_bits, q37o_bits, k37o_bits } } },\
{ 33,\
  { { p33s_bits, n33s_bits, b33s_bits, r33s_bits, q33s_bits, k33s_bits },\
    { p33o_bits, n33o_bits, b33o_bits, r33o_bits, q33o_bits, k33o_bits } } },\
{ 29,\
  { { p29s_bits, n29s_bits, b29s_bits, r29s_bits, q29s_bits, k29s_bits },\
    { p29o_bits, n29o_bits, b29o_bits, r29o_bits, q29o_bits, k29o_bits } } },\
{ 25,\
  { { p25s_bits, n25s_bits, b25s_bits, r25s_bits, q25s_bits, k25s_bits },\
    { p25o_bits, n25o_bits, b25o_bits, r25o_bits, q25o_bits, k25o_bits } } },\
{ 21,\
  { { p21s_bits, n21s_bits, b21s_bits, r21s_bits, q21s_bits, k21s_bits },\
    { p21o_bits, n21o_bits, b21o_bits, r21o_bits, q21o_bits, k21o_bits } } },\
{ 0,\
  { { NULL, NULL, NULL, NULL, NULL, NULL },\
    { NULL, NULL, NULL, NULL, NULL, NULL } } }\
}

#include "icon_white.bm"
#include "icon_black.bm"
#include "checkmark.bm"

==> xboard-4.2.3.tar.gz: xboard-4.2.3/bitmaps/bitmaps.h <==
/*
 * bitmaps.h - Include bitmap files for pieces and icons
 * $Id: bitmaps.h,v 1.11 2000/09/17 23:50:22 mann Exp $
 *
 * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
 * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
 *
 * The following terms apply to Digital Equipment Corporation's copyright
 * interest in XBoard:
 * ------------------------------------------------------------------------
 * All Rights Reserved
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and that
 * both that copyright notice and this permission notice appear in
 * supporting documentation, and that the name of Digital not be
 * used in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.
 *
 * DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
 * ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
 * DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
 * ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 * SOFTWARE.
 * ------------------------------------------------------------------------
 *
 * The following terms apply to the enhanced version of XBoard distributed
 * by the Free Software Foundation:
 * ------------------------------------------------------------------------
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * ------------------------------------------------------------------------
 *
 * See the file ChangeLog for a revision history.
 */

#include "p129s.bm"
#include "n129s.bm"
#include "b129s.bm"
#include "r129s.bm"
#include "q129s.bm"
#include "k129s.bm"

#include "p129o.bm"
#include "n129o.bm"
#include "b129o.bm"
#include "r129o.bm"
#include "q129o.bm"
#include "k129o.bm"

#include "p116s.bm"
#include "n116s.bm"
#include "b116s.bm"
#include "r116s.bm"
#include "q116s.bm"
#include "k116s.bm"

#include "p116o.bm"
#include "n116o.bm"
#include "b116o.bm"
#include "r116o.bm"
#include "q116o.bm"
#include "k116o.bm"

#include "p108s.bm"
#include "n108s.bm"
#include "b108s.bm"
#include "r108s.bm"
#include "q108s.bm"
#include "k108s.bm"

#include "p108o.bm"
#include "n108o.bm"
#include "b108o.bm"
#include "r108o.bm"
#include "q108o.bm"
#include "k108o.bm"

#include "p95s.bm"
#include "n95s.bm"
#include "b95s.bm"
#include "r95s.bm"
#include "q95s.bm"
#include "k95s.bm"

#include "p95o.bm"
#include "n95o.bm"
#include "b95o.bm"
#include "r95o.bm"
#include "q95o.bm"
#include "k95o.bm"

#include "p87s.bm"
#include "n87s.bm"
#include "b87s.bm"
#include "r87s.bm"
#include "q87s.bm"
#include "k87s.bm"

#include "p87o.bm"
#include "n87o.bm"
#include "b87o.bm"
#include "r87o.bm"
#include "q87o.bm"
#include "k87o.bm"

#include "p80s.bm"
#include "n80s.bm"
#include "b80s.bm"
#include "r80s.bm"
#include "q80s.bm"
#include "k80s.bm"

#include "p80o.bm"
#include "n80o.bm"
#include "b80o.bm"
#include "r80o.bm"
#include "q80o.bm"
#include "k80o.bm"

#include "p72s.bm"
#include "n72s.bm"
#include "b72s.bm"
#include "r72s.bm"
#include "q72s.bm"
#include "k72s.bm"

#include "p72o.bm"
#include "n72o.bm"
#include "b72o.bm"
#include "r72o.bm"
#include "q72o.bm"
#include "k72o.bm"

#include "p64s.bm"
#include "n64s.bm"
#include "b64s.bm"
#include "r64s.bm"
#include "q64s.bm"
#include "k64s.bm"

#include "p64o.bm"
#include "n64o.bm"
#include "b64o.bm"
#include "r64o.bm"
#include "q64o.bm"
#include "k64o.bm"

#include "p58s.bm"
#include "n58s.bm"
#include "b58s.bm"
#include "r58s.bm"
#include "q58s.bm"
#include "k58s.bm"

#include "p58o.bm"
#include "n58o.bm"
#include "b58o.bm"
#include "r58o.bm"
#include "q58o.bm"
#include "k58o.bm"

#include "p54s.bm"
#include "n54s.bm"
#include "b54s.bm"
#include "r54s.bm"
#include "q54s.bm"
#include "k54s.bm"

#include "p54o.bm"
#include "n54o.bm"
#include "b54o.bm"
#include "r54o.bm"
#include "q54o.bm"
#include "k54o.bm"

#include "p49s.bm"
#include "n49s.bm"
#include "b49s.bm"
#include "r49s.bm"
#include "q49s.bm"
#include "k49s.bm"

#include "p49o.bm"
#include "n49o.bm"
#include "b49o.bm"
#include "r49o.bm"
#include "q49o.bm"
#include "k49o.bm"

#include "p45s.bm"
#include "n45s.bm"
#include "b45s.bm"
#include "r45s.bm"
#include "q45s.bm"
#include "k45s.bm"

#include "p45o.bm"
#include "n45o.bm"
#include "b45o.bm"
#include "r45o.bm"
#include "q45o.bm"
#include "k45o.bm"

#include "p40s.bm"
#include "n40s.bm"
#include "b40s.bm"
#include "r40s.bm"
#include "q40s.bm"
#include "k40s.bm"

#include "p40o.bm"
#include "n40o.bm"
#include "b40o.bm"
#include "r40o.bm"
#include "q40o.bm"
#include "k40o.bm"

#include "p37s.bm"
#include "n37s.bm"
#include "b37s.bm"
#include "r37s.bm"
#include "q37s.bm"
#include "k37s.bm"

#include "p37o.bm"
#include "n37o.bm"
#include "b37o.bm"
#include "r37o.bm"
#include "q37o.bm"
#include "k37o.bm"

#include "p33s.bm"
#include "n33s.bm"
#include "b33s.bm"
#include "r33s.bm"
#include "q33s.bm"
#include "k33s.bm"

#include "p33o.bm"
#include "n33o.bm"
#include "b33o.bm"
#include "r33o.bm"
#include "q33o.bm"
#include "k33o.bm"

#include "p29s.bm"
#include "n29s.bm"
#include "b29s.bm"
#include "r29s.bm"
#include "q29s.bm"
#include "k29s.bm"

#include "p29o.bm"
#include "n29o.bm"
#include "b29o.bm"
#include "r29o.bm"
#include "q29o.bm"
#include "k29o.bm"

#include "p25s.bm"
#include "n25s.bm"
#include "b25s.bm"
#include "r25s.bm"
#include "q25s.bm"
#include "k25s.bm"

#include "p25o.bm"
#include "n25o.bm"
#include "b25o.bm"
#include "r25o.bm"
#include "q25o.bm"
#include "k25o.bm"

#include "p21s.bm"
#include "n21s.bm"
#include "b21s.bm"
#include "r21s.bm"
#include "q21s.bm"
#include "k21s.bm"

#include "p21o.bm"
#include "n21o.bm"
#include "b21o.bm"
#include "r21o.bm"
#include "q21o.bm"
#include "k21o.bm"

typedef struct {
    int squareSize;
    unsigned char *bits[2][6];
} BuiltInBits;

BuiltInBits builtInBits[] = {\
{ 129,\
  { { p129s_bits, n129s_bits, b129s_bits, r129s_bits, q129s_bits, k129s_bits },\
    { p129o_bits, n129o_bits, b129o_bits, r129o_bits, q129o_bits, k129o_bits } } },\
{ 116,\
  { { p116s_bits, n116s_bits, b116s_bits, r116s_bits, q116s_bits, k116s_bits },\
    { p116o_bits, n116o_bits, b116o_bits, r116o_bits, q116o_bits, k116o_bits } } },\
{ 108,\
  { { p108s_bits, n108s_bits, b108s_bits, r108s_bits, q108s_bits, k108s_bits },\
    { p108o_bits, n108o_bits, b108o_bits, r108o_bits, q108o_bits, k108o_bits } } },\
{ 95,\
  { { p95s_bits, n95s_bits, b95s_bits, r95s_bits, q95s_bits, k95s_bits },\
    { p95o_bits, n95o_bits, b95o_bits, r95o_bits, q95o_bits, k95o_bits } } },\
{ 87,\
  { { p87s_bits, n87s_bits, b87s_bits, r87s_bits, q87s_bits, k87s_bits },\
    { p87o_bits, n87o_bits, b87o_bits, r87o_bits, q87o_bits, k87o_bits } } },\
{ 80,\
  { { p80s_bits, n80s_bits, b80s_bits, r80s_bits, q80s_bits, k80s_bits },\
    { p80o_bits, n80o_bits, b80o_bits, r80o_bits, q80o_bits, k80o_bits } } },\
{ 72,\
  { { p72s_bits, n72s_bits, b72s_bits, r72s_bits, q72s_bits, k72s_bits },\
    { p72o_bits, n72o_bits, b72o_bits, r72o_bits, q72o_bits, k72o_bits } } },\
{ 64,\
  { { p64s_bits, n64s_bits, b64s_bits, r64s_bits, q64s_bits, k64s_bits },\
    { p64o_bits, n64o_bits, b64o_bits, r64o_bits, q64o_bits, k64o_bits } } },\
{ 58,\
  { { p58s_bits, n58s_bits, b58s_bits, r58s_bits, q58s_bits, k58s_bits },\
    { p58o_bits, n58o_bits, b58o_bits, r58o_bits, q58o_bits, k58o_bits } } },\
{ 54,\
  { { p54s_bits, n54s_bits, b54s_bits, r54s_bits, q54s_bits, k54s_bits },\
    { p54o_bits, n54o_bits, b54o_bits, r54o_bits, q54o_bits, k54o_bits } } },\
{ 49,\
  { { p49s_bits, n49s_bits, b49s_bits, r49s_bits, q49s_bits, k49s_bits },\
    { p49o_bits, n49o_bits, b49o_bits, r49o_bits, q49o_bits, k49o_bits } } },\
{ 45,\
  { { p45s_bits, n45s_bits, b45s_bits, r45s_bits, q45s_bits, k45s_bits },\
    { p45o_bits, n45o_bits, b45o_bits, r45o_bits, q45o_bits, k45o_bits } } },\
{ 40,\
  { { p40s_bits, n40s_bits, b40s_bits, r40s_bits, q40s_bits, k40s_bits },\
    { p40o_bits, n40o_bits, b40o_bits, r40o_bits, q40o_bits, k40o_bits } } },\
{ 37,\
  { { p37s_bits, n37s_bits, b37s_bits, r37s_bits, q37s_bits, k37s_bits },\
    { p37o_bits, n37o_bits, b37o_bits, r37o_bits, q37o_bits, k37o_bits } } },\
{ 33,\
  { { p33s_bits, n33s_bits, b33s_bits, r33s_bits, q33s_bits, k33s_bits },\
    { p33o_bits, n33o_bits, b33o_bits, r33o_bits, q33o_bits, k33o_bits } } },\
{ 29,\
  { { p29s_bits, n29s_bits, b29s_bits, r29s_bits, q29s_bits, k29s_bits },\
    { p29o_bits, n29o_bits, b29o_bits, r29o_bits, q29o_bits, k29o_bits } } },\
{ 25,\
  { { p25s_bits, n25s_bits, b25s_bits, r25s_bits, q25s_bits, k25s_bits },\
    { p25o_bits, n25o_bits, b25o_bits, r25o_bits, q25o_bits, k25o_bits } } },\
{ 21,\
  { { p21s_bits, n21s_bits, b21s_bits, r21s_bits, q21s_bits, k21s_bits },\
    { p21o_bits, n21o_bits, b21o_bits, r21o_bits, q21o_bits, k21o_bits } } },\
{ 0,\
  { { NULL, NULL, NULL, NULL, NULL, NULL },\
    { NULL, NULL, NULL, NULL, NULL, NULL } } }\
};
